@@ -1,5 +1,5 @@
  ###############################################################################
- #  Copyright 2011 Ian McIntosh <ian@openanswers.org>
+ #  Copyright 2022 Ian McIntosh <ian@openanswers.org>
  #  Copyright 2022 Georges Khaznadar <georgesk@debian.org> (migration to gtk3)
  #
  #  This program is free software; you can redistribute it and/or modify
@@ -23,20 +23,18 @@ class HelpWindow < GladeWindow
 	def initialize
 		super('help_window')
 		@window.signal_connect('delete_event') { hide }
-    @window.signal_connect('key_press_event') { |w,e|
-      if e.keyval == Gdk::Keyval::KEY_Escape
-        hide
-      end
-    }
+		@window.signal_connect('key_press_event') { |_window, event|
+			if event.keyval == Gdk::Keyval::KEY_Escape
+				hide
+			end
+		}
 	end
 
 	def on_close_button_clicked
 		hide
 	end
-  
 end
 
-
 # Local Variables:
 # tab-width: 2
 # End:
